@@ -334,8 +334,10 @@ int getGPSVersion (char **string)
 	  int n;
 	  getGPSMessage();
 	  n=data[-1];
+	  if (n<0)
+	    n=0;
 	  p=protocols=xmalloc(5*n/3+1);
-	  for ( ; n; n-=3)
+	  for ( ; n>0; n-=3)
 	    {
 	      tag=*s; udata=toshort(s+1); 
 	      /* translate each protocol tag and data to the string used in the docs */
